@@ -1,7 +1,9 @@
 from __future__ import annotations
 
+from dataclasses import asdict, is_dataclass
 from typing import Optional, Union
 from pathlib import Path
+import logging
 
 from airflow import AirflowException
 from airflow.models.baseoperator import BaseOperator
@@ -57,6 +59,7 @@ class DbtBaseOperator(BaseOperator):
         vars: Optional[dict[str, str]] = None,
         log_cache_events: Optional[bool] = False,
         bypass_cache: Optional[bool] = False,
+        xcom_push: Optional[bool] = False,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -67,6 +70,15 @@ class DbtBaseOperator(BaseOperator):
         self.vars = vars
         self.log_cache_events = log_cache_events
         self.bypass_cache = bypass_cache
+        self.xcom_push_flag = xcom_push
+
+        self.copy_logger_handlers("dbt")
+
+    def copy_logger_handlers(self, logger_name: str):
+        """Copy the instance's log handlers to another logger"""
+        logger = logging.getLogger(logger_name)
+        for handler in self.log.handlers:
+            logger.addHandler(handler)
 
     def execute(self, context: dict):
         """Execute dbt task with prepared arguments"""
@@ -79,7 +91,13 @@ class DbtBaseOperator(BaseOperator):
         if success is not True:
             raise AirflowException(f"dbt {self.task} {args} failed")
 
-        return res
+        if self.xcom_push_flag is True:
+            # Some dbt operations use dataclasses for its results,
+            # found in dbt.contracts.results. We use dataclasses.asdict
+            # to obtain a serializable dict for XCOM.
+            if is_dataclass(res):
+                return asdict(res)
+            return res
 
     def args_list(self) -> list[str]:
         """Build a list of arguments to pass to dbt"""
